import type { CancelablePromise } from "../core/CancelablePromise.js";
import type { BaseHttpRequest } from "../core/BaseHttpRequest.js";
export declare class BackendWalletService {
    readonly httpRequest: BaseHttpRequest;
    constructor(httpRequest: BaseHttpRequest);
    /**
     * Create backend wallet
     * Create a backend wallet.
     * @param requestBody
     * @returns any Default Response
     * @throws ApiError
     */
    create(requestBody?: {
        label?: string;
    }): CancelablePromise<{
        result: {
            walletAddress: string;
            status: string;
        };
    }>;
    /**
     * Remove backend wallet
     * Remove an existing backend wallet. NOTE: This is an irreversible action for local wallets. Ensure any funds are transferred out before removing a local wallet.
     * @param walletAddress
     * @returns any Default Response
     * @throws ApiError
     */
    removeBackendWallet(walletAddress: string): CancelablePromise<{
        result: {
            status: string;
        };
    }>;
    /**
     * Import backend wallet
     * Import an existing wallet as a backend wallet.
     * @param requestBody
     * @returns any Default Response
     * @throws ApiError
     */
    import(requestBody?: ({
        /**
         * AWS KMS key ID
         */
        awsKmsKeyId: string;
        /**
         * AWS KMS key ARN
         */
        awsKmsArn: string;
    } | {
        /**
         * GCP KMS key ID
         */
        gcpKmsKeyId: string;
        /**
         * GCP KMS key version ID
         */
        gcpKmsKeyVersionId: string;
    } | ({
        /**
         * The private key of the wallet to import
         */
        privateKey: string;
    } | {
        /**
         * The mnemonic phrase of the wallet to import
         */
        mnemonic: string;
    } | {
        /**
         * The encrypted JSON of the wallet to import
         */
        encryptedJson: string;
        /**
         * The password used to encrypt the encrypted JSON
         */
        password: string;
    }))): CancelablePromise<{
        result: {
            walletAddress: string;
            status: string;
        };
    }>;
    /**
     * Update backend wallet
     * Update a backend wallet.
     * @param requestBody
     * @returns any Default Response
     * @throws ApiError
     */
    update(requestBody: {
        walletAddress: string;
        label?: string;
    }): CancelablePromise<{
        result: {
            walletAddress: string;
            status: string;
        };
    }>;
    /**
     * Get balance
     * Get the native balance for a backend wallet.
     * @param chain Chain ID
     * @param walletAddress Backend wallet address
     * @returns any Default Response
     * @throws ApiError
     */
    getBalance(chain: string, walletAddress: string): CancelablePromise<{
        result: {
            walletAddress: string;
            name: string;
            symbol: string;
            decimals: number;
            value: string;
            displayValue: string;
        };
    }>;
    /**
     * Get all backend wallets
     * Get all backend wallets.
     * @param page The page of wallets to get.
     * @param limit The number of wallets to get per page.
     * @returns any Default Response
     * @throws ApiError
     */
    getAll(page?: number, limit?: number): CancelablePromise<{
        result: Array<{
            /**
             * Wallet Address
             */
            address: string;
            /**
             * Wallet Type
             */
            type: string;
            label: (string | null);
            awsKmsKeyId: (string | null);
            awsKmsArn: (string | null);
            gcpKmsKeyId: (string | null);
            gcpKmsKeyRingId: (string | null);
            gcpKmsLocationId: (string | null);
            gcpKmsKeyVersionId: (string | null);
            gcpKmsResourcePath: (string | null);
        }>;
    }>;
    /**
     * Transfer tokens
     * Transfer native currency or ERC20 tokens to another wallet.
     * @param chain Chain ID
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @param simulateTx Simulate the transaction on-chain without executing
     * @param xIdempotencyKey Transactions submitted with the same idempotency key will be de-duplicated. Only the last 100000 transactions are compared.
     * @returns any Default Response
     * @throws ApiError
     */
    transfer(chain: string, xBackendWalletAddress: string, requestBody: {
        /**
         * The recipient wallet address.
         */
        to: string;
        /**
         * The token address to transfer. Omit to transfer the chain's native currency (e.g. ETH on Ethereum).
         */
        currencyAddress: string;
        /**
         * The amount in ether to transfer. Example: "0.1" to send 0.1 ETH.
         */
        amount: string;
        txOverrides?: {
            /**
             * Gas limit for the transaction
             */
            gas?: string;
            /**
             * Maximum fee per gas
             */
            maxFeePerGas?: string;
            /**
             * Maximum priority fee per gas
             */
            maxPriorityFeePerGas?: string;
            /**
             * Amount of native currency to send
             */
            value?: string;
        };
    }, simulateTx?: boolean, xIdempotencyKey?: string): CancelablePromise<{
        result: {
            /**
             * Queue ID
             */
            queueId: string;
        };
    }>;
    /**
     * Withdraw funds
     * Withdraw all funds from this wallet to another wallet.
     * @param chain Chain ID
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @param simulateTx Simulate the transaction on-chain without executing
     * @param xIdempotencyKey Transactions submitted with the same idempotency key will be de-duplicated. Only the last 100000 transactions are compared.
     * @returns any Default Response
     * @throws ApiError
     */
    withdraw(chain: string, xBackendWalletAddress: string, requestBody: {
        /**
         * Address to withdraw all funds to
         */
        toAddress: string;
    }, simulateTx?: boolean, xIdempotencyKey?: string): CancelablePromise<{
        result: {
            transactionHash: string;
        };
    }>;
    /**
     * Send a transaction
     * Send a transaction with transaction parameters
     * @param chain Chain ID
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @param simulateTx Simulate the transaction on-chain without executing
     * @param xIdempotencyKey Transactions submitted with the same idempotency key will be de-duplicated. Only the last 100000 transactions are compared.
     * @param xAccountAddress Smart account address
     * @returns any Default Response
     * @throws ApiError
     */
    sendTransaction(chain: string, xBackendWalletAddress: string, requestBody: {
        toAddress?: string;
        data: string;
        value: string;
        txOverrides?: {
            /**
             * Gas limit for the transaction
             */
            gas?: string;
            /**
             * Maximum fee per gas
             */
            maxFeePerGas?: string;
            /**
             * Maximum priority fee per gas
             */
            maxPriorityFeePerGas?: string;
        };
    }, simulateTx?: boolean, xIdempotencyKey?: string, xAccountAddress?: string): CancelablePromise<{
        result: {
            /**
             * Queue ID
             */
            queueId: string;
        };
    }>;
    /**
     * Send a batch of raw transactions
     * Send a batch of raw transactions with transaction parameters
     * @param chain Chain ID
     * @param xBackendWalletAddress Backend wallet address
     * @param xIdempotencyKey Transactions submitted with the same idempotency key will be de-duplicated. Only the last 100000 transactions are compared.
     * @param requestBody
     * @returns any Default Response
     * @throws ApiError
     */
    sendTransactionBatch(chain: string, xBackendWalletAddress: string, xIdempotencyKey?: string, requestBody?: Array<{
        toAddress?: string;
        data: string;
        value: string;
        txOverrides?: {
            /**
             * Gas limit for the transaction
             */
            gas?: string;
            /**
             * Maximum fee per gas
             */
            maxFeePerGas?: string;
            /**
             * Maximum priority fee per gas
             */
            maxPriorityFeePerGas?: string;
            /**
             * Amount of native currency to send
             */
            value?: string;
        };
    }>): CancelablePromise<{
        result: {
            queueIds: Array<string>;
        };
    }>;
    /**
     * Sign a transaction
     * Sign a transaction
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @param xIdempotencyKey Transactions submitted with the same idempotency key will be de-duplicated. Only the last 100000 transactions are compared.
     * @returns any Default Response
     * @throws ApiError
     */
    signTransaction(xBackendWalletAddress: string, requestBody: {
        transaction: {
            to?: string;
            from?: string;
            nonce?: string;
            gasLimit?: string;
            gasPrice?: string;
            data?: string;
            value?: string;
            chainId?: number;
            type?: number;
            accessList?: any;
            maxFeePerGas?: string;
            maxPriorityFeePerGas?: string;
            customData?: Record<string, any>;
            ccipReadEnabled?: boolean;
        };
    }, xIdempotencyKey?: string): CancelablePromise<{
        result: string;
    }>;
    /**
     * Sign a message
     * Send a message
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @param xIdempotencyKey Transactions submitted with the same idempotency key will be de-duplicated. Only the last 100000 transactions are compared.
     * @returns any Default Response
     * @throws ApiError
     */
    signMessage(xBackendWalletAddress: string, requestBody: {
        message: string;
        isBytes?: boolean;
    }, xIdempotencyKey?: string): CancelablePromise<{
        result: string;
    }>;
    /**
     * Sign an EIP-712 message
     * Send an EIP-712 message ("typed data")
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @param xIdempotencyKey Transactions submitted with the same idempotency key will be de-duplicated. Only the last 100000 transactions are compared.
     * @returns any Default Response
     * @throws ApiError
     */
    signTypedData(xBackendWalletAddress: string, requestBody: {
        domain: Record<string, any>;
        types: Record<string, any>;
        value: Record<string, any>;
    }, xIdempotencyKey?: string): CancelablePromise<{
        result: string;
    }>;
    /**
     * Get recent transactions
     * Get recent transactions for this backend wallet.
     * @param status The status to query: 'queued', 'mined', 'errored', or 'cancelled'. Default: 'queued'
     * @param chain Chain ID
     * @param walletAddress Backend wallet address
     * @param page Specify the page number.
     * @param limit Specify the number of results to return per page.
     * @returns any Default Response
     * @throws ApiError
     */
    getTransactionsForBackendWallet(status: ('queued' | 'mined' | 'cancelled' | 'errored'), chain: string, walletAddress: string, page?: number, limit?: number): CancelablePromise<{
        result: {
            transactions: Array<{
                queueId: (string | null);
                /**
                 * The current state of the transaction.
                 */
                status: ('queued' | 'sent' | 'mined' | 'errored' | 'cancelled');
                chainId: (string | null);
                fromAddress: (string | null);
                toAddress: (string | null);
                data: (string | null);
                extension: (string | null);
                value: (string | null);
                nonce: (number | string | null);
                gasLimit: (string | null);
                gasPrice: (string | null);
                maxFeePerGas: (string | null);
                maxPriorityFeePerGas: (string | null);
                transactionType: (number | null);
                transactionHash: (string | null);
                queuedAt: (string | null);
                sentAt: (string | null);
                minedAt: (string | null);
                cancelledAt: (string | null);
                deployedContractAddress: (string | null);
                deployedContractType: (string | null);
                errorMessage: (string | null);
                sentAtBlockNumber: (number | null);
                blockNumber: (number | null);
                /**
                 * The number of retry attempts
                 */
                retryCount: number;
                retryGasValues: (boolean | null);
                retryMaxFeePerGas: (string | null);
                retryMaxPriorityFeePerGas: (string | null);
                signerAddress: (string | null);
                accountAddress: (string | null);
                target: (string | null);
                sender: (string | null);
                initCode: (string | null);
                callData: (string | null);
                callGasLimit: (string | null);
                verificationGasLimit: (string | null);
                preVerificationGas: (string | null);
                paymasterAndData: (string | null);
                userOpHash: (string | null);
                functionName: (string | null);
                functionArgs: (string | null);
                onChainTxStatus: (number | null);
                onchainStatus: ('success' | 'reverted' | null);
                effectiveGasPrice: (string | null);
                cumulativeGasUsed: (string | null);
            }>;
        };
    }>;
    /**
     * Get recent transactions by nonce
     * Get recent transactions for this backend wallet, sorted by descending nonce.
     * @param fromNonce The earliest nonce, inclusive.
     * @param chain Chain ID
     * @param walletAddress Backend wallet address
     * @param toNonce The latest nonce, inclusive. If omitted, queries up to the latest sent nonce.
     * @returns any Default Response
     * @throws ApiError
     */
    getTransactionsForBackendWalletByNonce(fromNonce: number, chain: string, walletAddress: string, toNonce?: number): CancelablePromise<{
        result: Array<{
            nonce: number;
            transaction: ({
                queueId: (string | null);
                /**
                 * The current state of the transaction.
                 */
                status: ('queued' | 'sent' | 'mined' | 'errored' | 'cancelled');
                chainId: (string | null);
                fromAddress: (string | null);
                toAddress: (string | null);
                data: (string | null);
                extension: (string | null);
                value: (string | null);
                nonce: (number | string | null);
                gasLimit: (string | null);
                gasPrice: (string | null);
                maxFeePerGas: (string | null);
                maxPriorityFeePerGas: (string | null);
                transactionType: (number | null);
                transactionHash: (string | null);
                queuedAt: (string | null);
                sentAt: (string | null);
                minedAt: (string | null);
                cancelledAt: (string | null);
                deployedContractAddress: (string | null);
                deployedContractType: (string | null);
                errorMessage: (string | null);
                sentAtBlockNumber: (number | null);
                blockNumber: (number | null);
                /**
                 * The number of retry attempts
                 */
                retryCount: number;
                retryGasValues: (boolean | null);
                retryMaxFeePerGas: (string | null);
                retryMaxPriorityFeePerGas: (string | null);
                signerAddress: (string | null);
                accountAddress: (string | null);
                target: (string | null);
                sender: (string | null);
                initCode: (string | null);
                callData: (string | null);
                callGasLimit: (string | null);
                verificationGasLimit: (string | null);
                preVerificationGas: (string | null);
                paymasterAndData: (string | null);
                userOpHash: (string | null);
                functionName: (string | null);
                functionArgs: (string | null);
                onChainTxStatus: (number | null);
                onchainStatus: ('success' | 'reverted' | null);
                effectiveGasPrice: (string | null);
                cumulativeGasUsed: (string | null);
            } | string);
        }>;
    }>;
    /**
     * Reset nonces
     * Reset nonces for all backend wallets. This is for debugging purposes and does not impact held tokens.
     * @returns any Default Response
     * @throws ApiError
     */
    resetNonces(): CancelablePromise<{
        result: {
            status: string;
        };
    }>;
    /**
     * Get nonce
     * Get the last used nonce for this backend wallet. This value managed by Engine may differ from the onchain value. Use `/backend-wallet/reset-nonces` if this value looks incorrect while idle.
     * @param chain Chain ID
     * @param walletAddress Backend wallet address
     * @returns any Default Response
     * @throws ApiError
     */
    getNonce(chain: string, walletAddress: string): CancelablePromise<{
        result: {
            nonce: number;
        };
    }>;
    /**
     * Simulate a transaction
     * Simulate a transaction with transaction parameters
     * @param chain Chain ID
     * @param xBackendWalletAddress Backend wallet address
     * @param requestBody
     * @param xIdempotencyKey Transactions submitted with the same idempotency key will be de-duplicated. Only the last 100000 transactions are compared.
     * @param xAccountAddress Smart account address
     * @returns any Default Response
     * @throws ApiError
     */
    simulateTransaction(chain: string, xBackendWalletAddress: string, requestBody: {
        /**
         * The contract address
         */
        toAddress: string;
        /**
         * The amount of native currency in wei
         */
        value?: string;
        /**
         * The function to call on the contract
         */
        functionName?: string;
        args?: Array<string>;
        /**
         * Raw calldata
         */
        data?: string;
    }, xIdempotencyKey?: string, xAccountAddress?: string): CancelablePromise<{
        result: {
            /**
             * Simulation Success
             */
            success: boolean;
        };
    }>;
}
