import type { CancelablePromise } from "../core/CancelablePromise.js";
import type { BaseHttpRequest } from "../core/BaseHttpRequest.js";
export declare class ContractSubscriptionsService {
    readonly httpRequest: BaseHttpRequest;
    constructor(httpRequest: BaseHttpRequest);
    /**
     * Get contract subscriptions
     * Get all contract subscriptions.
     * @returns any Default Response
     * @throws ApiError
     */
    getContractSubscriptions(): CancelablePromise<{
        result: Array<{
            id: string;
            chainId: number;
            contractAddress: string;
            webhook?: {
                url: string;
                name: (string | null);
                secret?: string;
                eventType: string;
                active: boolean;
                createdAt: string;
                id: number;
            };
            processEventLogs: boolean;
            filterEvents: Array<string>;
            processTransactionReceipts: boolean;
            filterFunctions: Array<string>;
            createdAt: string;
        }>;
    }>;
    /**
     * Add contract subscription
     * Subscribe to event logs and transaction receipts for a contract.
     * @param requestBody
     * @returns any Default Response
     * @throws ApiError
     */
    addContractSubscription(requestBody: {
        /**
         * The chain for the contract.
         */
        chain: string;
        /**
         * The address for the contract.
         */
        contractAddress: string;
        /**
         * Webhook URL
         */
        webhookUrl?: string;
        /**
         * If true, parse event logs for this contract.
         */
        processEventLogs: boolean;
        /**
         * A case-sensitive list of event names to filter event logs. Parses all event logs by default.
         */
        filterEvents?: Array<string>;
        /**
         * If true, parse transaction receipts for this contract.
         */
        processTransactionReceipts: boolean;
        /**
         * A case-sensitive list of function names to filter transaction receipts. Parses all transaction receipts by default.
         */
        filterFunctions?: Array<string>;
    }): CancelablePromise<{
        result: {
            id: string;
            chainId: number;
            contractAddress: string;
            webhook?: {
                url: string;
                name: (string | null);
                secret?: string;
                eventType: string;
                active: boolean;
                createdAt: string;
                id: number;
            };
            processEventLogs: boolean;
            filterEvents: Array<string>;
            processTransactionReceipts: boolean;
            filterFunctions: Array<string>;
            createdAt: string;
        };
    }>;
    /**
     * Remove contract subscription
     * Remove an existing contract subscription
     * @param requestBody
     * @returns any Default Response
     * @throws ApiError
     */
    removeContractSubscription(requestBody: {
        /**
         * The ID for an existing contract subscription.
         */
        contractSubscriptionId: string;
    }): CancelablePromise<{
        result: {
            status: string;
        };
    }>;
    /**
     * Get subscribed contract indexed block range
     * Gets the subscribed contract's indexed block range
     * @param chain Chain ID or name
     * @param contractAddress Contract address on the chain
     * @returns any Default Response
     * @throws ApiError
     */
    getContractIndexedBlockRange(chain: string, contractAddress: string): CancelablePromise<{
        result: {
            chain: string;
            contractAddress: string;
            fromBlock: number;
            toBlock: number;
            status: string;
        };
    }>;
    /**
     * Get last processed block
     * Get the last processed block for a chain.
     * @param chain Chain name or ID
     * @returns any Default Response
     * @throws ApiError
     */
    getLatestBlock(chain: string): CancelablePromise<{
        result: {
            lastBlock: number;
            status: string;
        };
    }>;
}
